.. -*- coding: utf-8 -*-

Javascript
----------

XXX jquery...

Conventions
~~~~~~~~~~~

XXX external_resources variable
    naming convention
    request.add_js


CubicWeb javascrip api
~~~~~~~~~~~~~~~~~~~~~~
XXX explain diffenrent files and main functions
